---
name: "\U0001F41B Bug Report"
about: Create a report for a reproducible bug
title: ""
labels: ""
assignees: ""
---

### Environment

- Installation type: <!-- homebrew/pip -->
- Python version: <!-- Example: 3.7.13 -->
- Wilfred version: <!-- Example: 1.0, 2.0, …, master -->

### Steps to Reproduce

<!-- What did you expect to happen? -->

### Expected Behavior

<!-- What happened instead? -->

### Observed Behavior
